package xl.controller;

import xl.model.XLModel;
import xl.gui.Editor;
import xl.gui.SlotLabel;
import xl.gui.StatusLabel;

/**
 * The controller for the editor.
 * 
 * The controller is responsible for handling the editor actions.
 */
public class EditorController {
    private XLModel xlModel;
    private Editor editor;
    private SlotLabel currentSlot;
    private StatusLabel statusLabel;

    public EditorController(XLModel xlModel, StatusLabel statusLabel) {
        this.xlModel = xlModel;
        this.statusLabel = statusLabel;
    }

    public void setCurrentSlot(SlotLabel currentSlot) {
        this.currentSlot = currentSlot;
    }

    public void setEditor(Editor editor) {
        this.editor = editor;
    }

    public void handleEditorAction() {
        String content = editor.getText();
        String address = currentSlot.getAddress();

        if (content.isEmpty()) {
            boolean isOkRemove = xlModel.remove(address);
            if (isOkRemove) {
                currentSlot.setText("");
                statusLabel.setText("");
            } else {
                statusLabel.setText(xlModel.getStatus());
            }
        } else if (content.charAt(0) == '#') {
            xlModel.add(address, content);
            currentSlot.setText(content.substring(1));
            statusLabel.setText("");
        } else {
            xlModel.add(address, content);
            if (xlModel.getStatus().equals("")) {
                content = xlModel.getAddressValue(address);
                currentSlot.setText(content);
            } else {
                statusLabel.setText(xlModel.getStatus());
            }

        }
    }
}
