package xl.controller;
import java.awt.Color;
import xl.model.XLModel;
import xl.gui.*;

/**
 * The controller for the slot labels.
 * 
 * The controller is responsible for handling the slot label actions.
 */
public class SlotLabelController {
    private XLModel xlModel;
    private Editor editor;
    private SlotLabel currentSlot;
    private EditorController editorController;
    private StatusLabel statusLabel;
    private CurrentLabel currentLabel;

    public SlotLabelController(XLModel xlModel, Editor editor, StatusLabel statusLabel) {
        this.xlModel = xlModel;
        this.editor = editor;
        this.statusLabel = statusLabel;
    }
      
    public void setCurrentLabel(CurrentLabel currentLabel) {
        this.currentLabel = currentLabel;
    }
    
    public void setCurrentSlot(SlotLabel currentSlot) {
        this.currentSlot = currentSlot;
    }

    public void setEditorController(EditorController editorController) {
        this.editorController = editorController;
    }

    public void handleSlotClick(SlotLabel slotLabel) {
        // Retrieve the address of the clicked slot
        String address = slotLabel.getAddress();
        currentLabel.setText(address);
        xlModel.setCurrentAddress(address);
       
        // Clear the status label
        statusLabel.setText("");
        
        // Reset the background color of the previous slot
        currentSlot.setBackground(Color.WHITE);

        // Set the background color of the clicked slot
        slotLabel.setBackground(Color.YELLOW);
        currentSlot = slotLabel;
        editorController.setCurrentSlot(currentSlot);

        // Retrieve the content of the clicked slot
        String content = xlModel.getAddressContent(address);

        // Set the content of the clicked slot in the editor
        editor.setText(content);
    }
}