package xl.gui;

import static java.awt.BorderLayout.CENTER;
import static java.awt.BorderLayout.NORTH;
import static java.awt.BorderLayout.SOUTH;

import javax.swing.JFrame;
import javax.swing.JPanel;

import xl.controller.EditorController;
import xl.controller.SlotLabelController;
import xl.menu.XLMenuBar;
import xl.model.XLModel;

public class XL extends JFrame {

    private static final int ROWS = 10, COLUMNS = 8;
    private XLCounter counter;
    private StatusLabel statusLabel = new StatusLabel();
    private XLList xlList;

    public XL(XL oldXL, XLModel XLModel) {
        this(oldXL.xlList, oldXL.counter, XLModel);
    }

    public XL(XLList xlList, XLCounter counter, XLModel XLModel) {
        super("Window " + counter);
        this.xlList = xlList;
        this.counter = counter;
        xlList.add(this);
        counter.increment();

        EditorController editorController = new EditorController(XLModel, statusLabel);
        Editor editor = new Editor(editorController);
        editorController.setEditor(editor);

        SlotLabelController slotLabelController = new SlotLabelController(XLModel, editor, statusLabel);
        slotLabelController.setEditorController(editorController);

        JPanel statusPanel = new StatusPanel(statusLabel, XLModel, slotLabelController);
        JPanel sheetPanel = new SheetPanel(ROWS, COLUMNS, XLModel, slotLabelController, editorController);

        add(NORTH, statusPanel);
        add(CENTER, editor);
        add(SOUTH, sheetPanel);
        setJMenuBar(new XLMenuBar(this, xlList, statusLabel, XLModel));
        pack();
        setDefaultCloseOperation(EXIT_ON_CLOSE);
        setResizable(false);
        setVisible(true);
    }

    public void rename(String title) {
        setTitle(title);
        xlList.setChanged();
    }

    public static void main(String[] args) {
        new XL(new XLList(), new XLCounter(), new XLModel());
    }
}
